import { BaseEvent } from '@/application/base/baseEvent'
import { SocketEvent } from '@/application/enums'
import MapManager from '@/managers/mapManager'
import ChatService from '@/services/chatService'

type TypePayload = {
  message: string
}

export default class ChatMessageEvent extends BaseEvent {
  public listen(): void {
    this.socket.on(SocketEvent.CHAT_MESSAGE, this.handleEvent.bind(this))
  }

  private async handleEvent(data: TypePayload, callback: (response: boolean) => void): Promise<void> {
    try {
      if (!data.message || ChatService.isCommand(data.message)) return

      const mapCharacter = MapManager.getCharacterById(this.socket.characterId!)
      if (!mapCharacter) {
        this.logger.error('chat:message error', 'Character not found')
        return
      }

      const character = mapCharacter.character

      if (await ChatService.sendMapMessage(character.getId(), data.message)) {
        return callback(true)
      }

      callback(false)
    } catch (error: any) {
      this.logger.error('chat:message error', error.message)
      callback(false)
    }
  }
}
