import { BaseEvent } from '@/application/base/baseEvent'
import { CharacterGender, CharacterRace, SocketEvent } from '@/application/enums'
import type { UUID } from '@/application/types'
import CharacterTypeRepository from '@/repositories/characterTypeRepository'
import SpriteRepository from '@/repositories/spriteRepository'

type Payload = {
  id: UUID
  name: string
  gender: CharacterGender
  race: CharacterRace
  isSelectable: boolean
  spriteId: UUID
}

export default class CharacterTypeUpdateEvent extends BaseEvent {
  public listen(): void {
    this.socket.on(SocketEvent.GM_CHARACTERTYPE_UPDATE, this.handleEvent.bind(this))
  }

  private async handleEvent(data: Payload, callback: (success: boolean) => void): Promise<void> {
    try {
      if (!(await this.isCharacterGM())) return

      const characterTypeRepository = new CharacterTypeRepository()
      const characterType = await characterTypeRepository.getById(data.id)
      if (!characterType) return callback(false)

      const spriteRepository = new SpriteRepository()
      const sprite = await spriteRepository.getById(data.spriteId)
      if (!sprite) return callback(false)

      await characterType.setName(data.name).setGender(data.gender).setRace(data.race).setIsSelectable(data.isSelectable).setSprite(sprite).save()

      return callback(true)
    } catch (error) {
      console.error(error)
      return callback(false)
    }
  }
}
